About
=====

This library gathers a collection of music signal processing algorithms written
by several people. The documentation of each algorithms contains a brief
description and references to the corresponding papers.

Credits
-------

Many thanks to everyone who contributed to aubio, including:

  - Martin Hermant (`MartinHN <https://github.com/MartinHN>`_)
  - Eduard Müller (`emuell <https://github.com/emuell>`_)
  - Nils Philippsen (`nphilipp <https://github.com/nphilipp>`_)
  - Tres Seaver (`tseaver <https://github.com/tseaver>`_)
  - Dirkjan Rijnders (`dirkjankrijnders <https://github.com/dirkjankrijnders>`_)
  - Jeffrey Kern (`anwserman <https:/ /github.com/anwserman>`_)
  - Sam Alexander (`sxalexander <https://github.com/sxalexander>`_)

Special thanks to Juan Pablo Bello, Chris Duxbury, Samer Abdallah, Alain de
Cheveigne for their help. Also many thanks to Miguel Ramirez and Nicolas Wack
for their advices and help fixing bugs.

Publications
------------

Substantial informations about several of the algorithms and their evaluation
are gathered in:

  - Paul Brossier, `Automatic annotation of musical audio for interactive
    systems <https://aubio.org/phd>`_, PhD thesis, Centre for Digital music,
    Queen Mary University of London, London, UK, 2006.

Additional results obtained with this software were discussed in the following
papers:

  - P. M. Brossier and J. P. Bello and M. D. Plumbley, `Real-time temporal
    segmentation of note objects in music signals
    <https://aubio.org/articles/brossier04fastnotes.pdf>`_ in *Proceedings of
    the International Computer Music Conference*, 2004, Miami, Florida, ICMA

  - P. M. Brossier and J. P. Bello and M. D. Plumbley, `Fast labelling of note
    objects in music signals
    <https://aubio.org/articles/brossier04fastnotes.pdf>`, in *Proceedings of
    the International Symposium on Music Information Retrieval*, 2004,
    Barcelona, Spain

Citation
--------

Please refer to the Zenodo link in the file README.md to cite this release.

Copyright
---------

Copyright © 2003-2017 Paul Brossier <piem@aubio.org>

License
-------

aubio is a `free <https://www.debian.org/intro/free>`_ and `open source
<http://www.opensource.org/docs/definition.php>`_ software; **you** can
redistribute it and/or modify it under the terms of the `GNU
<https://www.gnu.org/>`_ `General Public License
<https://www.gnu.org/licenses/gpl.html>`_ as published by the `Free Software
Foundation <https://fsf.org>`_, either version 3 of the License, or (at your
option) any later version.

.. note::

   aubio is not MIT or BSD licensed. Contact us if you need it in your
   commercial product.
